==> igniteui-react-18.7.0-beta.2.tgz: package/esm5/lib/LinearProgress.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ProgressBase } from "./ProgressBase";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
import { LinearProgressLabelAlign_$type } from "./LinearProgressLabelAlign";
/**
 * @hidden
 */
var LinearProgress = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(LinearProgress, _super);
    function LinearProgress() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(LinearProgress.prototype, "o", {
        get: function () {
            var ret_ = this.c.n("striped");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.w("striped", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LinearProgress.prototype, "n", {
        get: function () {
            var ret_ = this.c.n("labelAlign");
            if ((ret_ === undefined && this.___rawMode)) {
                return undefined;
            }
            ret_ = enumGetBox(LinearProgressLabelAlign_$type, EnumUtil.getEnumValue(LinearProgressLabelAlign_$type, this.c.f(LinearProgressLabelAlign_$type, ret_)));
            return EnumUtil.getEnumValue(LinearProgressLabelAlign_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(LinearProgressLabelAlign_$type, a);
            value_ = WCNativeHelper.camel(value_.toString());
            this.c.w("labelAlign", value_);
        },
        enumerable: false,
        configurable: true
    });
    LinearProgress.$t = markType(LinearProgress, 'LinearProgress', ProgressBase.$);
    return LinearProgress;
}(ProgressBase));
export { LinearProgress };

==> igniteui-react-18.7.5-beta.2.tgz: package/esm5/lib/LinearProgress.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ProgressBase } from "./ProgressBase";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
import { LinearProgressLabelAlign_$type } from "./LinearProgressLabelAlign";
/**
 * @hidden
 */
var LinearProgress = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(LinearProgress, _super);
    function LinearProgress() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(LinearProgress.prototype, "o", {
        get: function () {
            var ret_ = this.c.n("striped");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.w("striped", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LinearProgress.prototype, "n", {
        get: function () {
            var ret_ = this.c.n("labelAlign");
            if ((ret_ === undefined && this.___rawMode)) {
                return undefined;
            }
            ret_ = enumGetBox(LinearProgressLabelAlign_$type, EnumUtil.getEnumValue(LinearProgressLabelAlign_$type, this.c.f(LinearProgressLabelAlign_$type, ret_)));
            return EnumUtil.getEnumValue(LinearProgressLabelAlign_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(LinearProgressLabelAlign_$type, a);
            value_ = WCNativeHelper.getActualName(value_);
            value_ = WCNativeHelper.camel(value_);
            this.c.w("labelAlign", value_);
        },
        enumerable: false,
        configurable: true
    });
    LinearProgress.$t = markType(LinearProgress, 'LinearProgress', ProgressBase.$);
    return LinearProgress;
}(ProgressBase));
export { LinearProgress };
